@@ -31,7 +31,7 @@ Initializes the default classes for Spork::Shlomify.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< shlomif@iglu.org.il >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 LICENSE
 
